@@ -135,6 +135,16 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         return $sftp;
     }
 
+    static function demoCallback($length)
+    {
+        $r = substr(self::$buffer, 0, $length);
+        self::$buffer = substr(self::$buffer, $length);
+        if (strlen($r)) {
+            return $r;
+        }
+        return null;
+    }
+
     /**
      * @depends testStatOnDir
      */
@@ -160,16 +170,6 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         return $sftp;
     }
 
-    static function callback($length)
-    {
-        $r = substr(self::$buffer, 0, $length);
-        self::$buffer = substr(self::$buffer, $length);
-        if (strlen($r)) {
-            return $r;
-        }
-        return null;
-    }
-
     /**
      * @depends testStatOnDir
      */
@@ -177,7 +177,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
     {
         self::$buffer = self::$exampleData;
         $this->assertTrue(
-            $sftp->put('file1.txt', array(__CLASS__, 'callback'), $sftp::SOURCE_CALLBACK),
+            $sftp->put('file1.txt', array(__CLASS__, 'demoCallback'), $sftp::SOURCE_CALLBACK),
             'Failed asserting that example data could be successfully put().'
         );
 
@@ -439,8 +439,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
      */
     public function testReadlink($sftp)
     {
-        $this->assertInternalType(
-            'string',
+        $this->assertIsString(
             $sftp->readlink('symlink'),
             'Failed asserting that a symlink\'s target could be read'
         );
@@ -455,14 +454,12 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
     public function testStatOnCWD($sftp)
     {
         $stat = $sftp->stat('.');
-        $this->assertInternalType(
-            'array',
+        $this->assertIsArray(
             $stat,
             'Failed asserting that stat on . returns an array'
         );
         $lstat = $sftp->lstat('.');
-        $this->assertInternalType(
-            'array',
+        $this->assertIsArray(
             $lstat,
             'Failed asserting that lstat on . returns an array'
         );
@@ -604,8 +601,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
             'Failed asserting that scratch directory could ' .
             'be created.'
         );
-        $this->assertInternalType(
-            'array',
+        $this->assertIsArray(
             $sftp->stat(self::$scratchDir),
             'Failed asserting that stat on an existant empty directory returns an array'
         );
