@@ -79,7 +79,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
         $decoded = $asn1->decodeBER(base64_decode($str));
         $result = $asn1->asn1map($decoded[0], $AS_REP);
 
-        $this->assertInternalType('array', $result);
+        $this->assertIsArray($result);
     }
 
     /**
@@ -231,7 +231,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
         $decoded = $asn1->decodeBER(base64_decode($str));
         $result = $asn1->asn1map($decoded[0], $AS_REP);
 
-        $this->assertInternalType('array', $result);
+        $this->assertIsArray($result);
     }
 
     /**
@@ -276,7 +276,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
     {
         $asn1 = new ASN1();
         $decoded = $asn1->decodeBER(base64_decode('MBaAFJtUo7c00HsI5EPZ4bkICfkOY2Pv'));
-        $this->assertInternalType('string', $decoded[0]['content'][0]['content']);
+        $this->assertIsString($decoded[0]['content'][0]['content']);
     }
 
     /**
@@ -286,7 +286,7 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
     {
         $asn1 = new ASN1();
         $decoded = $asn1->decodeBER("\xa0\x00");
-        $this->assertInternalType('array', $decoded);
+        $this->assertIsArray($decoded);
         $this->assertCount(0, $decoded[0]['content']);
     }
 
@@ -369,27 +369,27 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
      */
     public function testExplicitImplicitDate()
     {
-        $map = [
+        $map = array(
             'type'     => ASN1::TYPE_SEQUENCE,
-            'children' => [
-                'notBefore' => [
+            'children' => array(
+                'notBefore' => array(
                                              'constant' => 0,
                                              'optional' => true,
                                              'implicit' => true,
-                                             'type' => ASN1::TYPE_GENERALIZED_TIME],
-                'notAfter'  => [
+                                             'type' => ASN1::TYPE_GENERALIZED_TIME),
+                'notAfter'  => array(
                                              'constant' => 1,
                                              'optional' => true,
                                              'implicit' => true,
-                                             'type' => ASN1::TYPE_GENERALIZED_TIME]
-            ]
-        ];
+                                             'type' => ASN1::TYPE_GENERALIZED_TIME)
+            )
+        );
 
         $asn1 = new ASN1();
         $a = pack('H*', '3026a011180f32303137303432313039303535305aa111180f32303138303432313230353935395a');
         $a = $asn1->decodeBER($a);
         $a = $asn1->asn1map($a[0], $map);
 
-        $this->assertInternalType('array', $a);
+        $this->assertIsArray($a);
     }
 }
